@@ -1,12 +1,15 @@
 from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
-from modeltranslation.admin import TranslationAdmin
 
-from flatpages_i18n.models import FlatPage_i18n, MenuItem
+from modeltranslation.admin import TranslationAdmin
 from mptt.admin import MPTTModelAdmin
 
+from forms import FlatpageForm
+from models import FlatPage_i18n, MenuItem
+
 
 class FlatPageAdmin(MPTTModelAdmin, TranslationAdmin):
+    form = FlatpageForm
     mptt_level_indent = 0
 
     fieldsets = (
@@ -22,13 +25,13 @@ class FlatPageAdmin(MPTTModelAdmin, TranslationAdmin):
     search_fields = ('url', 'title')
 
     def indented_title(self, obj):
-        level =  getattr(obj, obj._mptt_meta.level_attr)
+        level = getattr(obj, obj._mptt_meta.level_attr)
 
         if level is 0:
             return obj
 
         level_indicator = ''.join(['-' for i in range(level)])
-        return '%s %s' % (level_indicator, obj.title)
+        return '%s %s' % (level_indicator, unicode(obj))
 
 admin.site.register(FlatPage_i18n, FlatPageAdmin)
 
@@ -36,17 +39,17 @@ admin.site.register(FlatPage_i18n, FlatPageAdmin)
 class MenuItemAdmin(MPTTModelAdmin, TranslationAdmin):
     mptt_level_indent = 0
 
-    fields = ['parent', 'title', 'flatpage', 'has_custom_link', 'custom_link']
-    list_display = ('indented_title', 'parent', 'weight')
+    fields = ['parent', 'title', 'flatpage', 'machine_name', 'has_custom_link', 'custom_link', ]
+    list_display = ('indented_title', 'machine_name', 'parent', 'weight')
     list_editable = ['parent', 'weight']
 
     def indented_title(self, obj):
-        level =  getattr(obj, obj._mptt_meta.level_attr)
+        level = getattr(obj, obj._mptt_meta.level_attr)
 
         if level is 0:
             return obj
 
         level_indicator = ''.join(['-' for i in range(level)])
-        return '%s %s' % (level_indicator, obj.title)
+        return '%s %s' % (level_indicator, unicode(obj))
 
 admin.site.register(MenuItem, MenuItemAdmin)
